@@ -4,7 +4,7 @@ use warnings;
 package Dist::Zilla::PluginBundle::DAGOLDEN;
 # ABSTRACT: Dist::Zilla configuration the way DAGOLDEN does it
 
-our $VERSION = '0.074';
+our $VERSION = '0.075';
 
 # Dependencies
 use Moose 0.99;
@@ -23,7 +23,7 @@ use Dist::Zilla::Plugin::RunExtraTests          ();
 use Dist::Zilla::Plugin::CheckMetaResources 0.001  ();
 use Dist::Zilla::Plugin::CheckPrereqsIndexed 0.002 ();
 use Dist::Zilla::Plugin::Git::Contributors 0.007   ();
-use Dist::Zilla::Plugin::CopyFilesFromBuild           ();
+use Dist::Zilla::Plugin::CopyFilesFromBuild::Filtered ();
 use Dist::Zilla::Plugin::CPANFile                     ();
 use Dist::Zilla::Plugin::Git::NextVersion             ();
 use Dist::Zilla::Plugin::Git::CheckFor::CorrectBranch ();
@@ -370,7 +370,8 @@ sub configure {
         # copy files from build back to root for inclusion in VCS;
         # for auto_version we want cpanfile.  For embedded version we want Makefile.PL
         [
-            CopyFilesFromBuild => { copy => $self->auto_version ? 'cpanfile' : 'Makefile.PL' }
+            'CopyFilesFromBuild::Filtered' =>
+              { copy => $self->auto_version ? 'cpanfile' : 'Makefile.PL' }
         ],
 
         # manifest -- must come after all generated files
@@ -469,7 +470,7 @@ Dist::Zilla::PluginBundle::DAGOLDEN - Dist::Zilla configuration the way DAGOLDEN
 
 =head1 VERSION
 
-version 0.074
+version 0.075
 
 =head1 SYNOPSIS
 
@@ -493,6 +494,7 @@ following dist.ini:
   exclude_filename = README.mkdn  ; skip this generated file
   exclude_filename = META.json    ; skip this generated file
   exclude_filename = cpanfile     ; skip this generated file
+  exclude_filename = Makefile.PL  ; skip this generated file
 
   [PruneCruft]        ; default stuff to skip
   [ManifestSkip]      ; if -f MANIFEST.SKIP, skip those, too
@@ -567,7 +569,7 @@ following dist.ini:
   [Manifest]          ; create MANIFEST
 
   ; copy cpanfile back to repo dis
-  [CopyFilesFromBuild]
+  [CopyFilesFromBuild::Filtered]
   copy = Makefile.PL
 
   ; before release
